priority property
The priority for the notification.
This property only has impact on devices running Android 8.0 (API level 26) +. Later than this, they use the channel importance instead.
Implementation
final AndroidNotificationPriority priority;
The priority for the notification.
This property only has impact on devices running Android 8.0 (API level 26) +. Later than this, they use the channel importance instead.
final AndroidNotificationPriority priority;