Bounds<T extends num>.unsafe constructor

const Bounds<T extends num>.unsafe(
  1. Point<T> min,
  2. Point<T> max
)

Create a Bounds instance without checking if min is actually the minimum and max is actually the maximum.

Implementation

const Bounds.unsafe(this.min, this.max);