buttonIndexedTextBuilder property
This is a custom builder method that
allows you to set your own custom text for buttons based on their index.
If you do not set up buttonIndexedBuilder and buttonBuilder, the text will be displayed on top of the button.
Implementation
final GroupButtonIndexedTextBuilder? buttonIndexedTextBuilder;