selectedIndex property
int?
get
selectedIndex
Selected button index in case when you using radio type
Implementation
int? get selectedIndex => _selectedIndex;
Selected button index in case when you using radio type
int? get selectedIndex => _selectedIndex;