InteractionOptions class final

All interactive options for FlutterMap

Annotations

Constructors

InteractionOptions({int flags = InteractiveFlag.all, bool debugMultiFingerGestureWinner = false, bool enableMultiFingerGestureRace = false, double rotationThreshold = 20.0, int rotationWinGestures = MultiFingerGesture.rotate, double pinchZoomThreshold = 0.5, int pinchZoomWinGestures = MultiFingerGesture.pinchZoom | MultiFingerGesture.pinchMove, double pinchMoveThreshold = 40.0, int pinchMoveWinGestures = MultiFingerGesture.pinchZoom | MultiFingerGesture.pinchMove, double scrollWheelVelocity = 0.005, CursorKeyboardRotationOptions cursorKeyboardRotationOptions = const CursorKeyboardRotationOptions()})
Create a new InteractionOptions instance to be used in MapOptions.interactionOptions.
const

Properties

cursorKeyboardRotationOptions → CursorKeyboardRotationOptions
Options to configure cursor/keyboard rotation
final
debugMultiFingerGestureWinner → bool
Prints multi finger gesture winner Helps to fine adjust rotationThreshold and pinchZoomThreshold and pinchMoveThreshold Note: only takes effect if enableMultiFingerGestureRace is true
final
enableMultiFingerGestureRace → bool
If true then rotationThreshold and pinchZoomThreshold and pinchMoveThreshold will race If multiple gestures win at the same time then precedence: pinchZoomWinGestures > rotationWinGestures > pinchMoveWinGestures
final
flags → int
See InteractiveFlag for custom settings
final
hashCode → int
The hash code for this object.
no setteroverride
pinchMoveThreshold → double
Pinch Move threshold default is 40.0 (note: this doesn't take any effect on drag) Map starts to move when pinchMoveThreshold has been achieved or another multi finger gesture wins which allows MultiFingerGesture.pinchMove.
final
pinchMoveWinGestures → int
When pinchMoveThreshold wins over rotationThreshold and pinchZoomThreshold then pinchMoveWinGestures gestures will be used. By default MultiFingerGesture.pinchMove and MultiFingerGesture.pinchZoom gestures will take effect see MultiFingerGesture for custom settings
final
pinchZoomThreshold → double
Pinch Zoom threshold default is 0.5 Map starts to zoom when pinchZoomThreshold has been achieved or another multi finger gesture wins which allows MultiFingerGesture.pinchZoom Note: if MapOptions.interactiveFlags.flags doesn't contain InteractiveFlag.pinchZoom or enableMultiFingerGestureRace is false then zoom cannot win.
final
pinchZoomWinGestures → int
When pinchZoomThreshold wins over rotationThreshold and pinchMoveThreshold then pinchZoomWinGestures gestures will be used. By default MultiFingerGesture.pinchZoom and MultiFingerGesture.pinchMove gestures will take effect see MultiFingerGesture for custom settings
final
rotationThreshold → double
Rotation threshold in degree default is 20.0 Map starts to rotate when rotationThreshold has been achieved or another multi finger gesture wins which allows MultiFingerGesture.rotate.
final
rotationWinGestures → int
When rotationThreshold wins over pinchZoomThreshold and pinchMoveThreshold then rotationWinGestures gestures will be used. By default only MultiFingerGesture.rotate gesture will take effect see MultiFingerGesture for custom settings
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollWheelVelocity → double
The used velocity how fast the map should zoom in or out by scrolling with the scroll wheel of a mouse.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override