LatLng class

Coordinates in Degrees

final Location location = new Location(10.000002,12.00001);

Constructors

LatLng(double latitude, double longitude)
const
LatLng.fromJson(Map<String, dynamic> json)
LatLng.fromSexagesimal(String str)
Converts sexagesimal string into a lat/long value
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
latitude → double
final
latitudeInRad → double
no setter
longitude → double
final
longitudeInRad → double
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
round({int decimals = 6}) → LatLng
toJson() → Map<String, dynamic>
toSexagesimal() → String
Converts lat/long values into sexagesimal
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override