point property
Screen point of the detected hit
See coordinate for the geographical coordinate which was hit.
Implementation
final Point<double> point;
Screen point of the detected hit
See coordinate for the geographical coordinate which was hit.
final Point<double> point;