providesAppNotificationSettings property
Whether or not system displays an application notification settings button
Apple devices only.
Implementation
final AppleNotificationSetting providesAppNotificationSettings;
Whether or not system displays an application notification settings button
Apple devices only.
final AppleNotificationSetting providesAppNotificationSettings;