Projection class abstract
The abstract base Projection class, used for coordinate reference systems like Epsg3857. Inherit from this class if you want to create or implement your own CRS.
- Annotations
Constructors
-
Projection(Bounds<
double> ? bounds) -
Base constructor for the abstract Projection class that sets the
required fields.
const
Properties
-
bounds
→ Bounds<
double> ? -
The Bounds for the coordinates of this Projection.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
project(
LatLng latlng) → Point< double> - Converts a LatLng to a coordinates and returns them as Point object.
-
projectXY(
LatLng latlng) → (double, double) - Converts a LatLng to geometry coordinates.
-
toString(
) → String -
A string representation of this object.
inherited
-
unproject(
Point< num> point) → LatLng - unproject a cartesian Point to LatLng.
-
unprojectXY(
double x, double y) → LatLng - unproject cartesian x,y coordinates to LatLng.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited