Projection constructor
Base constructor for the abstract Projection class that sets the required fields.
Implementation
const Projection(this.bounds);
Base constructor for the abstract Projection class that sets the required fields.
const Projection(this.bounds);