RichAttributionWidgetAnimation class abstract interface

Animation provider interface for a RichAttributionWidget

The popup box's animation is handled/built by popupAnimationBuilder for full flexibility.

The open/close button's animation is fixed to a fade animation provided by AnimatedSwitcher, but its curve and duration can still be customized through buttonDuration and buttonCurve.

Can be extensively customized by implementing a custom RichAttributionWidgetAnimation, or the prebuilt FadeRAWA and ScaleRAWA animations can be used with limited customization.

Annotations

Properties

buttonCurve → Curve
The curve of the animation used when toggling the state of the open/close button
final
buttonDuration → Duration
The duration of the animation used when toggling the state of the open/close button
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
popupAnimationBuilder({required BuildContext context, required bool isExpanded, required RichAttributionWidget config, required Widget child}) → Widget
Builder for the popup box animation
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited