SphericalMercator class

Spherical mercator projection

Inheritance
Annotations

Constructors

SphericalMercator()
Constant constructor for the SphericalMercator projection.
const

Properties

bounds Bounds<double>?
The Bounds for the coordinates of this Projection.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
project(LatLng latlng) Point<double>
Converts a LatLng to a coordinates and returns them as Point object.
inherited
projectXY(LatLng latlng) → (double, double)
Converts a LatLng to geometry coordinates.
override
toString() String
A string representation of this object.
inherited
unproject(Point<num> point) LatLng
unproject a cartesian Point to LatLng.
inherited
unprojectXY(double x, double y) LatLng
unproject cartesian x,y coordinates to LatLng.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

projectLat(double latitude) double
Project the latitude for this Crs
projectLng(double longitude) double
Project the longitude for this Crs

Constants

maxLatitude → const double
The maximum latitude
r → const int
The radius