effectiveDirection property
VerticalDirection
get
effectiveDirection
The effective direction of the suggestions box. This may or may not be the same as direction.
If you wish to change the direction of the suggestions box, use direction.
This value is typically set by the SuggestionsField widget.
You should not need to set it manually.
This value can be used to determine e.g. the direction of the ScrollView inside the suggestions box.
Implementation
VerticalDirection get effectiveDirection => _effectiveDirection;
set
effectiveDirection
(VerticalDirection value)
Implementation
set effectiveDirection(VerticalDirection value) {
if (_effectiveDirection == value) return;
_effectiveDirection = value;
notifyListeners();
}