gainFocus property
bool
get
gainFocus
Whether the suggestions box should gain the focus when it is opened.
Implementation
bool get gainFocus => _gainFocus;
Whether the suggestions box should gain the focus when it is opened.
bool get gainFocus => _gainFocus;