ProductStatus enum

Inheritance
Available extensions

Values

isNew → const ProductStatus
const ProductStatus("New", "نو", 100)
isWorked → const ProductStatus
const ProductStatus("Worked", "کارکرده", 101)
isLikeNew → const ProductStatus
const ProductStatus("Like new", "در حد نو", 102)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → int
final
title → String
final
titleTr1 → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<ProductStatus>
A constant List of the values in this enum, in order of their declaration.