SortLists enum
Values
- atoZ → const SortLists
-
const SortLists("0") - zToA → const SortLists
-
const SortLists("1") - mostRecent → const SortLists
-
const SortLists("2") - oldest → const SortLists
-
const SortLists("3") - cheapest → const SortLists
-
const SortLists("4") - mostExpensive → const SortLists
-
const SortLists("5") - orderByVotes → const SortLists
-
const SortLists("6")
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited