isFilled property
- @Deprecated('Prefer setting `color` to null to disable filling, or a `Color` to enable filling of that color. ' 'This parameter will be removed to simplify the API, as this was a remnant of pre-null-safety. ' 'The default of this parameter is now `null` and will use the rules above - the option is retained so as not to break APIs. ' 'This feature was deprecated (and the default changed) after v7.')
final
DEPRECATED
Prefer setting color to null to disable filling, or a Color to enable
filling of that color.
This parameter will be removed to simplify the API, as this was a remnant of pre-null-safety.
The default of this parameter is now null and will use the rules above -
the option is retained so as not to break APIs.
This feature was deprecated (and the default changed) after v7.
Set to true if the Polygon should be filled with a color.
Implementation
@Deprecated(
'Prefer setting `color` to null to disable filling, or a `Color` to enable filling of that color. '
'This parameter will be removed to simplify the API, as this was a remnant of pre-null-safety. '
'The default of this parameter is now `null` and will use the rules above - the option is retained so as not to break APIs. '
'This feature was deprecated (and the default changed) after v7.',
)
final bool? isFilled;